==> open-xchange-documents-backend_7.6.0.orig.tar.bz2: open-xchange-documents-backend-7.6.0/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/DefinedNames.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_DefinedNames complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_DefinedNames">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="definedName" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_DefinedName" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_DefinedNames", propOrder = {
    "definedName"
})
public class DefinedNames implements Child
{

    protected List<CTDefinedName> definedName;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the definedName property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the definedName property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getDefinedName().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTDefinedName }
     * 
     * 
     */
    public List<CTDefinedName> getDefinedName() {
        if (definedName == null) {
            definedName = new ArrayList<CTDefinedName>();
        }
        return this.definedName;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> open-xchange-documents-backend_7.6.2.orig.tar.bz2: open-xchange-documents-backend-7.6.2/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/DefinedNames.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;

import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_DefinedNames complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_DefinedNames">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="definedName" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_DefinedName" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_DefinedNames", propOrder = {
    "definedName"
})
public class DefinedNames implements Child
{
    @XmlTransient
    protected List<CTDefinedName> definedName;
    @XmlTransient
    private Object parent;
    @XmlTransient
    private HashMap<String, CTDefinedName> definedNameMap;

    /**
     * Gets the value of the definedName property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the definedName property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getDefinedName().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTDefinedName }
     *
     *
     */
    @XmlElement
    public List<CTDefinedName> getDefinedName() {
        if(definedNameMap!=null) {
            definedName = new ArrayList<CTDefinedName>(getDefinedNameMap().values());
            definedNameMap = null;
        }
        else if(definedName==null) {
            definedName = new ArrayList<CTDefinedName>();
        }
        return definedName;
    }

    public static String getDefinedNameKey(Long localSheetId, String name) {
        if(localSheetId!=null) {
            return localSheetId.toString() + "." + name;
        }
        return "." + name;
    }
    public HashMap<String, CTDefinedName> getDefinedNameMap() {
        if(definedName!=null) {
            definedNameMap = new HashMap<String, CTDefinedName>(definedName.size());
            for(CTDefinedName defName:definedName) {
                definedNameMap.put(getDefinedNameKey(defName.localSheetId, defName.getName()), defName);
            }
            definedName = null;
        }
        else if(definedNameMap==null) {
            definedNameMap = new HashMap<String, CTDefinedName>();
        }
        return definedNameMap;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     *
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     *
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);

        // calling this once to remove double entries using the same name
        getDefinedNameMap();
    }
}
